@@ -1,13 +1,19 @@
 from ape.exceptions import CompilerError
 
 
-class VyperInstallError(CompilerError):
+class VyperCompilerPluginError(CompilerError):
+    """
+    An error raised in the Vyper compiler.
+    """
+
+
+class VyperInstallError(VyperCompilerPluginError):
     """
     An error raised failing to install Vyper.
     """
 
 
-class VyperCompileError(CompilerError):
+class VyperCompileError(VyperCompilerPluginError):
     """
     A compiler-specific error in Vyper.
     """
@@ -15,7 +21,7 @@ class VyperCompileError(CompilerError):
     def __init__(self, err: Exception):
         self.base_err = err
         if hasattr(err, "stderr_data"):
-            message = err.stderr_data  # type: ignore
+            message = err.stderr_data
         else:
             message = str(err)
 
