@@ -11,7 +11,7 @@ BASE_CONTRACTS_PATH = Path(__file__).parent / "contracts"
 
 # Currently, this is the only version specified from a pragma spec
 OLDER_VERSION_FROM_PRAGMA = Version("0.2.8")
-VERSION_FROM_PRAGMA = Version("0.3.4")
+VERSION_FROM_PRAGMA = Version("0.3.7")
 
 
 def contract_test_cases(passing: bool) -> List[str]:
@@ -19,7 +19,7 @@ def contract_test_cases(passing: bool) -> List[str]:
     Returns test-case names for outputting nicely with pytest.
     """
     suffix = "passing_contracts" if passing else "failing_contracts"
-    return [p.name for p in (BASE_CONTRACTS_PATH / suffix).glob("*.vy")]
+    return [p.name for p in (BASE_CONTRACTS_PATH / suffix).glob("*.vy") if p.is_file()]
 
 
 PASSING_CONTRACT_NAMES = contract_test_cases(True)
@@ -32,7 +32,9 @@ EXPECTED_FAIL_MESSAGES = {
 
 def test_compile_project(project):
     contracts = project.load_contracts()
-    assert len(contracts) == 5
+    assert len(contracts) == len(
+        [p.name for p in (BASE_CONTRACTS_PATH / "passing_contracts").glob("*.vy") if p.is_file()]
+    )
     assert contracts["contract"].source_id == "contract.vy"
     assert contracts["contract_no_pragma"].source_id == "contract_no_pragma.vy"
     assert contracts["older_version"].source_id == "older_version.vy"
@@ -67,17 +69,24 @@ def test_get_version_map(project, compiler):
     ]
     actual = compiler.get_version_map(vyper_files)
     expected_versions = (OLDER_VERSION_FROM_PRAGMA, VERSION_FROM_PRAGMA)
-    unexpected_versions = [str(k) for k in actual.keys() if k not in expected_versions]
-    fail_msg = f"Unexpected versions founds: {''.join(unexpected_versions)}"
-    assert not unexpected_versions, fail_msg
+
+    for version, sources in actual.items():
+        if version in expected_versions:
+            continue
+
+        sources = ", ".join([p.name for p in actual[version]])
+        fail_message = f"Unexpected version '{version}' with sources: {sources}"
+        pytest.fail(fail_message)
+
     assert len(actual[OLDER_VERSION_FROM_PRAGMA]) == 1
-    assert len(actual[VERSION_FROM_PRAGMA]) == 4
+    assert len(actual[VERSION_FROM_PRAGMA]) == 5
     assert actual[OLDER_VERSION_FROM_PRAGMA] == {project.contracts_folder / "older_version.vy"}
     assert actual[VERSION_FROM_PRAGMA] == {
         project.contracts_folder / "contract.vy",
         project.contracts_folder / "contract_no_pragma.vy",
         project.contracts_folder / "contract_with_dev_messages.vy",
         project.contracts_folder / "use_iface.vy",
+        project.contracts_folder / "use_iface2.vy",
     }
 
 
@@ -94,7 +103,7 @@ def test_compiler_data_in_manifest(project):
     for compiler in (vyper_028, vyper_034):
         assert compiler.name == "vyper"
 
-    assert len(vyper_034.contractTypes) == 4
+    assert len(vyper_034.contractTypes) == 5
     assert len(vyper_028.contractTypes) == 1
     assert "contract" in vyper_034.contractTypes
     assert "older_version" in vyper_028.contractTypes
@@ -125,3 +134,12 @@ def test_compile_parse_dev_messages(compiler):
     assert contract.dev_messages[16] == "dev: baz"
     assert contract.dev_messages[20] == "dev: 你好，猿"
     assert 23 not in contract.dev_messages
+
+
+def test_get_imports(compiler, project):
+    vyper_files = [
+        x for x in project.contracts_folder.iterdir() if x.is_file() and x.suffix == ".vy"
+    ]
+    actual = compiler.get_imports(vyper_files)
+    assert actual["use_iface.vy"] == ["interfaces/IFace.vy"]
+    assert actual["use_iface2.vy"] == ["interfaces/IFace.vy"]
